Module telexide_fork::api
source · Expand description
Modules
- This modules provides all the objects describing the payloads to be send to the different telegram API endpoints
Structs
- A default implementation of the
APItrait. - The response object that gets returned from the telegram API
Enums
- This enum represents all the telegram API endpoints.
Traits
- This trait provides methods for interacting with the telegram API.