Struct telexide_fork::api::APIClient [−][src]
pub struct APIClient { /* fields omitted */ }Expand description
A default implementation of the API trait.
It requires your bot token in order to interact with the telegram API and
also allows you to configure your own hyper::Client for it to use.
Using the default APIClient is as easy as:
use telexide_fork::api::{APIClient, API, types::SendMessage};
let token = String::from("test token");
let message = SendMessage::new(chat_id, "hi!");
let client = APIClient::new_default(&token);
client.send_message(message).await;In most cases you would want to get updates though and the Client is
best suited for that, as it allows for easier handling of those updates
Implementations
pub fn new<T: ToString>(
hyper_client: Option<Client<HttpsConnector<HttpConnector>>>,
token: &T
) -> Self
pub fn new<T: ToString>(
hyper_client: Option<Client<HttpsConnector<HttpConnector>>>,
token: &T
) -> Self
Creates a new APIClient with the provided token and hyper client (if
it is Some).
Creates a new APIClient with the provided token and the default hyper
client.
Sends a request to the provided APIEndpoint with the data provided
(does not support files)
gets a reference to the underlying hyper client, for example so you can make custom api requests