pub struct Context {
pub api: Arc<Box<dyn API + Send>>,
pub data: Arc<RwLock<ShareMap>>,
}
The context object is an utility object that gets passed to all event
handlers, it provides access to the API client and to any custom data you
have set in the data object.
The API client, implementing the API trait
A clone of Client::data, see its documentation for more detail
Performs copy-assignment from
source.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.