Struct telexide_fork::client::UpdatesStream
source · pub struct UpdatesStream { /* private fields */ }Expand description
The stream of incoming updates, created by long polling the telegram API using their getUpdates endpoint.
In most use-cases, this will be handled for you by the Client
and the new updates then dispatched to your eventhandlers.
Example
use futures::StreamExt;
use telexide_fork::{
api::APIClient,
client::UpdatesStream
};
#[tokio::main]
async fn main() {
let token = String::from("test token");
let mut stream = UpdatesStream::new(
Arc::new(
Box::new(
APIClient::new_default(&token)
)
)
);
while let Some(poll) = stream.next().await {
match poll {
Ok(update) => {
println!("ID of the update received: {}", update.update_id);
},
Err(err) => return,
}
}
}Implementations
sourceimpl UpdatesStream
impl UpdatesStream
sourcepub fn new(api: Arc<Box<dyn API + Send>>) -> Self
pub fn new(api: Arc<Box<dyn API + Send>>) -> Self
creates a new update stream using the provided API
sourcepub fn set_limit(&mut self, limit: usize) -> &mut Self
pub fn set_limit(&mut self, limit: usize) -> &mut Self
Sets the maximum amount of updates retrieved in one API call
sourcepub fn set_timout(&mut self, timeout: usize) -> &mut Self
pub fn set_timout(&mut self, timeout: usize) -> &mut Self
Set the timeout in seconds for long polling. Defaults to 5. Should be positive, short polling should be used for testing purposes only.
sourcepub fn set_allowed_updates(&mut self, allowed: Vec<UpdateType>) -> &mut Self
pub fn set_allowed_updates(&mut self, allowed: Vec<UpdateType>) -> &mut Self
Set which update types you want to receive
sourcepub fn add_allowed_updates(&mut self, allowed: UpdateType) -> &mut Self
pub fn add_allowed_updates(&mut self, allowed: UpdateType) -> &mut Self
Add an update type to the list of update types you want to receive
sourcepub fn remove_allowed_updates(&mut self, to_remove: &UpdateType) -> &mut Self
pub fn remove_allowed_updates(&mut self, to_remove: &UpdateType) -> &mut Self
Remove an update type from the list of update types you want to receive