pub struct Webhook { /* private fields */ }
Handles listening to the telegram webhook and will provide you with the
incoming updates
creates a new Webhook based on the provided WebhookOptions
starts the webhandling and returns a Receiver, which will allow you
to receive the incoming updates
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.