Module telexide_fork::framework[][src]

The framework provides a customizable way to manage your bots commands

Structs

The error to be returned from a command.

A utility for easily managing commands.

Type Definitions

A type alias for an std Result with the CommandError as the Err and () as the Ok