Enum telexide_fork::model::ReplyMarkup
source · pub enum ReplyMarkup {
InlineKeyboardMarkup(InlineKeyboardMarkup),
ReplyKeyboardMarkup(ReplyKeyboardMarkup),
ReplyKeyboardRemove(ReplyKeyboardRemove),
ForceReply(ForceReply),
}Expand description
Enum object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
Variants
InlineKeyboardMarkup(InlineKeyboardMarkup)
ReplyKeyboardMarkup(ReplyKeyboardMarkup)
ReplyKeyboardRemove(ReplyKeyboardRemove)
ForceReply(ForceReply)