Struct telexide_fork::model::raw::RawMessage
source · pub struct RawMessage {Show 56 fields
pub message_id: i64,
pub from: Option<User>,
pub sender_chat: Option<RawChat>,
pub date: DateTime<Utc>,
pub chat: RawChat,
pub forward_from: Option<User>,
pub forward_from_chat: Option<RawChat>,
pub forward_from_message_id: Option<i64>,
pub forward_signature: Option<String>,
pub forward_sender_name: Option<String>,
pub forward_date: Option<DateTime<Utc>>,
pub reply_to_message: Option<Box<RawMessage>>,
pub via_bot: Option<User>,
pub edit_date: Option<DateTime<Utc>>,
pub media_group_id: Option<String>,
pub author_signature: Option<String>,
pub text: Option<String>,
pub entities: Option<Vec<MessageEntity>>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub audio: Option<Audio>,
pub document: Option<Document>,
pub animation: Option<Animation>,
pub game: Option<Game>,
pub photo: Option<Vec<PhotoSize>>,
pub sticker: Option<Sticker>,
pub video: Option<Video>,
pub voice: Option<Voice>,
pub video_note: Option<VideoNote>,
pub caption: Option<String>,
pub contact: Option<Contact>,
pub location: Option<Location>,
pub venue: Option<Venue>,
pub poll: Option<Poll>,
pub dice: Option<Dice>,
pub new_chat_members: Option<Vec<User>>,
pub left_chat_member: Option<User>,
pub new_chat_title: Option<String>,
pub new_chat_photo: Option<Vec<PhotoSize>>,
pub delete_chat_photo: bool,
pub group_chat_created: bool,
pub supergroup_chat_created: bool,
pub channel_chat_created: bool,
pub message_auto_delete_timer_changed: Option<MessageAutoDeleteTimerChanged>,
pub migrate_to_chat_id: Option<i64>,
pub migrate_from_chat_id: Option<i64>,
pub pinned_message: Option<Box<RawMessage>>,
pub invoice: Option<Invoice>,
pub successful_payment: Option<SuccessfulPayment>,
pub connected_website: Option<String>,
pub passport_data: Option<PassportData>,
pub proximity_alert_triggered: Option<ProximityAlertTriggered>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub voice_chat_scheduled: Option<VoiceChatScheduled>,
pub voice_chat_started: Option<VoiceChatStarted>,
pub voice_chat_ended: Option<VoiceChatEnded>,
pub voice_chat_participants_invited: Option<VoiceChatParticipantsInvited>,
}Expand description
The raw message, for most usages the Message object is easier to use
Fields
message_id: i64from: Option<User>sender_chat: Option<RawChat>date: DateTime<Utc>chat: RawChatforward_from: Option<User>forward_from_chat: Option<RawChat>forward_from_message_id: Option<i64>forward_signature: Option<String>forward_sender_name: Option<String>forward_date: Option<DateTime<Utc>>reply_to_message: Option<Box<RawMessage>>via_bot: Option<User>edit_date: Option<DateTime<Utc>>media_group_id: Option<String>text: Option<String>entities: Option<Vec<MessageEntity>>caption_entities: Option<Vec<MessageEntity>>audio: Option<Audio>document: Option<Document>animation: Option<Animation>game: Option<Game>photo: Option<Vec<PhotoSize>>sticker: Option<Sticker>video: Option<Video>voice: Option<Voice>video_note: Option<VideoNote>caption: Option<String>contact: Option<Contact>location: Option<Location>venue: Option<Venue>poll: Option<Poll>dice: Option<Dice>new_chat_members: Option<Vec<User>>left_chat_member: Option<User>new_chat_title: Option<String>new_chat_photo: Option<Vec<PhotoSize>>delete_chat_photo: boolgroup_chat_created: boolsupergroup_chat_created: boolchannel_chat_created: boolmessage_auto_delete_timer_changed: Option<MessageAutoDeleteTimerChanged>migrate_to_chat_id: Option<i64>migrate_from_chat_id: Option<i64>pinned_message: Option<Box<RawMessage>>invoice: Option<Invoice>successful_payment: Option<SuccessfulPayment>connected_website: Option<String>passport_data: Option<PassportData>proximity_alert_triggered: Option<ProximityAlertTriggered>reply_markup: Option<InlineKeyboardMarkup>voice_chat_scheduled: Option<VoiceChatScheduled>voice_chat_started: Option<VoiceChatStarted>voice_chat_ended: Option<VoiceChatEnded>voice_chat_participants_invited: Option<VoiceChatParticipantsInvited>Trait Implementations
sourceimpl Clone for RawMessage
impl Clone for RawMessage
sourcefn clone(&self) -> RawMessage
fn clone(&self) -> RawMessage
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RawMessage
impl Debug for RawMessage
sourceimpl<'de> Deserialize<'de> for RawMessage
impl<'de> Deserialize<'de> for RawMessage
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<Message> for RawMessage
impl From<Message> for RawMessage
sourcefn from(message: Message) -> RawMessage
fn from(message: Message) -> RawMessage
Converts to this type from the input type.
sourceimpl From<RawMessage> for Message
impl From<RawMessage> for Message
sourcefn from(raw: RawMessage) -> Message
fn from(raw: RawMessage) -> Message
Converts to this type from the input type.
sourceimpl PartialEq<RawMessage> for RawMessage
impl PartialEq<RawMessage> for RawMessage
sourcefn eq(&self, other: &RawMessage) -> bool
fn eq(&self, other: &RawMessage) -> bool
This method tests for
self and other values to be equal, and is used
by ==.