Struct telexide_fork::model::raw::RawUpdate[][src]

pub struct RawUpdate {
Show 14 fields pub update_id: i64, pub message: Option<RawMessage>, pub edited_message: Option<RawMessage>, pub channel_post: Option<RawMessage>, pub edited_channel_post: Option<RawMessage>, pub inline_query: Option<InlineQuery>, pub chosen_inline_result: Option<ChosenInlineResult>, pub callback_query: Option<CallbackQuery>, pub shipping_query: Option<ShippingQuery>, pub pre_checkout_query: Option<PreCheckoutQuery>, pub poll: Option<Poll>, pub poll_answer: Option<PollAnswer>, pub my_chat_member: Option<ChatMemberUpdated>, pub chat_member: Option<ChatMemberUpdated>,
}
The raw update, for most usages the Update object is easier to use

Fields

update_id: i64

The update’s unique identifier. Update identifiers start from a certain positive number and increase sequentially. If there are no new updates for at least a week, then identifier of the next update will be chosen randomly instead of sequentially.

message: Option<RawMessage>

New incoming message of any kind — text, photo, sticker, etc.

edited_message: Option<RawMessage>

New version of a message that is known to the bot and was edited.

channel_post: Option<RawMessage>

New incoming channel post of any kind — text, photo, sticker, etc.

edited_channel_post: Option<RawMessage>

New version of a channel post that is known to the bot and was edited.

inline_query: Option<InlineQuery>

New incoming inline query.

chosen_inline_result: Option<ChosenInlineResult>

The result of an inline query that was chosen by a user and sent to their chat partner.

callback_query: Option<CallbackQuery>

New incoming callback query.

shipping_query: Option<ShippingQuery>

New incoming shipping query. Only for invoices with flexible price.

pre_checkout_query: Option<PreCheckoutQuery>

New incoming pre-checkout query. Contains full information about checkout.

poll: Option<Poll>

New poll state. Bots receive only updates about stopped polls and polls, which are sent by the bot.

poll_answer: Option<PollAnswer>

A user changed their answer in a non-anonymous poll. Bots receive new votes only in polls that were sent by the bot itself.

my_chat_member: Option<ChatMemberUpdated>

The bot’s chat member status was updated in a chat. For private chats, this update is received only when the bot is blocked or unblocked by the user.

chat_member: Option<ChatMemberUpdated>

A chat member’s status was updated in a chat. The bot must be an administrator in the chat and must explicitly specify “chat_member” in the list of allowed_updates to receive these updates.