Struct telexide_fork::model::Animation [−][src]
pub struct Animation {
pub file_id: String,
pub file_unique_id: String,
pub width: usize,
pub height: usize,
pub duration: usize,
pub thumb: Option<PhotoSize>,
pub mime_type: Option<String>,
pub file_size: Option<usize>,
pub file_name: Option<String>,
}Expand description
This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
width: usizeVideo width as defined by sender
height: usizeVideo height as defined by sender
duration: usizeDuration of the video in seconds as defined by sender
thumb: Option<PhotoSize>Animation thumbnail as defined by sender
mime_type: Option<String>MIME type of the file as defined by sender
file_size: Option<usize>File size
file_name: Option<String>Original animation filename as defined by sender