Struct telexide_fork::model::ChatMemberUpdated
source · pub struct ChatMemberUpdated {
pub chat: Chat,
pub from: User,
pub date: DateTime<Utc>,
pub old_chat_member: ChatMember,
pub new_chat_member: ChatMember,
pub invite_link: Option<ChatInviteLink>,
}Expand description
Represents changes in the status of a chat member.
Fields
chat: ChatChat the user belongs to
from: UserPerformer of the action, which resulted in the change
date: DateTime<Utc>Date the change was done
old_chat_member: ChatMemberPrevious information about the chat member
new_chat_member: ChatMemberNew information about the chat member
invite_link: Option<ChatInviteLink>Chat invite link, which was used by the user to join the chat; for joining by invite link events only.