Struct telexide_fork::model::Dice[][src]

pub struct Dice {
    pub emoji: String,
    pub value: u8,
}
This object represents a dice with a random value from 1 to 6 for currently supported base emoji.

Fields

emoji: String

Emoji on which the dice throw animation is based

value: u8

Value of the dice, 1-6 for “🎲”, “🎯” and “🎳” base emoji, 1-5 for “🏀” and “⚽” base emoji, 1-64 for “🎰” base emoji