Struct telexide_fork::model::Document [−][src]
pub struct Document {
pub file_id: String,
pub file_unique_id: String,
pub thumb: Option<PhotoSize>,
pub file_name: Option<String>,
pub mime_type: Option<String>,
pub file_size: Option<usize>,
}Expand description
This object represents a general file (as opposed to photos, voice messages and audio files).
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
thumb: Option<PhotoSize>Document thumbnail as defined by sender
file_name: Option<String>Original filename as defined by sender
mime_type: Option<String>MIME type of the file as defined by sender
file_size: Option<usize>File size