Struct telexide_fork::model::EncryptedCredentials [−][src]
Contains data required for decrypting and authenticating
EncryptedPassportElement. See the Telegram Passport Documentation
for a complete description of the data decryption and authentication
processes.
Fields
data: StringBase64-encoded encrypted JSON-serialized data with unique user’s payload, data hashes and secrets required for EncryptedPassportElement decryption and authentication
hash: StringBase64-encoded data hash for data authentication
secret: StringBase64-encoded secret, encrypted with the bot’s public RSA key, required for data decryption