Struct telexide_fork::model::File
source · pub struct File {
pub file_id: String,
pub file_unique_id: String,
pub file_size: Option<i64>,
pub file_path: Option<String>,
}Expand description
This object represents a file ready to be downloaded.
The file can be downloaded via the link https://api.telegram.org/file/bot<token>/<file_path>.
It is guaranteed that the link will be valid for at least 1 hour.
When the link expires, a new one can be requested by calling get_file.
Note: The maximum file size to download is 20 MB
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
file_size: Option<i64>File size, if known
file_path: Option<String>File path. Use https://api.telegram.org/file/bot<token>/<file_path> to get the file.
It is guaranteed that the link will be valid for at least 1 hour. When
the link expires, a new one can be requested by calling getFile
again.