Struct telexide_fork::model::InlineQuery[][src]

pub struct InlineQuery {
    pub id: String,
    pub from: User,
    pub location: Option<Location>,
    pub query: String,
    pub offset: String,
    pub chat_type: Option<ChatType>,
}
This object represents an incoming inline query. When the user sends an empty query, your bot could return some default or trending results.

Fields

id: String

Unique identifier for this query

from: User

Sender

location: Option<Location>

Sender location, only for bots that request user location

query: String

Text of the query (up to 256 characters)

offset: String

Offset of the results to be returned, can be controlled by the bot

chat_type: Option<ChatType>

Type of the chat, from which the inline query was sent. Can be either “sender” for a private chat with the inline query sender, “private”, “group”, “supergroup”, or “channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat.