pub struct Invoice {
    pub title: String,
    pub description: String,
    pub start_parameter: String,
    pub currency: String,
    pub total_amount: usize,
}
This object contains basic information about an invoice.

Fields

title: String

Product name

description: String

Product description

start_parameter: String

Unique bot deep-linking parameter that can be used to generate this invoice

currency: String

Three-letter ISO 4217 currency code

total_amount: usize

Total price in the smallest units of the currency (integer, not float). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).