Struct telexide_fork::model::MaskPosition [−][src]
pub struct MaskPosition {
pub point: MaskPoint,
pub x_shift: f64,
pub y_shift: f64,
pub scale: f64,
}Expand description
This object describes the position on faces where a mask should be placed by default.
Fields
point: MaskPointThe part of the face relative to which the mask should be placed
x_shift: f64Shift by X-axis measured in widths of the mask scaled to the face size, from left to right. For example, choosing -1.0 will place mask just to the left of the default mask position.
y_shift: f64Shift by Y-axis measured in heights of the mask scaled to the face size, from top to bottom. For example, 1.0 will place the mask just below the default mask position.
scale: f64Mask scaling coefficient. For example, 2.0 means double size.