Struct telexide_fork::model::PassportFile
source · pub struct PassportFile {
pub file_id: String,
pub file_unique_id: String,
pub file_size: i64,
pub file_date: DateTime<Utc>,
}Expand description
This object represents a file uploaded to Telegram Passport. Currently all Telegram Passport files are in JPEG format when decrypted and don’t exceed 10MB.
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
file_size: i64File size
file_date: DateTime<Utc>Unix time when the file was uploaded