Struct telexide_fork::model::PollAnswer[][src]

pub struct PollAnswer {
    pub poll_id: String,
    pub user: User,
    pub option_ids: Vec<usize>,
}
This object represents an answer of a user in a non-anonymous poll.

Fields

poll_id: String

Unique poll identifier

user: User

The user, who changed the answer to the poll

option_ids: Vec<usize>

0-based identifiers of answer options, chosen by the user. May be empty if the user retracted their vote