Struct telexide_fork::model::PreCheckoutQuery [−][src]
pub struct PreCheckoutQuery {
pub id: String,
pub from: User,
pub currency: String,
pub total_amount: usize,
pub invoice_payload: String,
pub shipping_option_id: Option<String>,
pub order_info: Option<OrderInfo>,
}Expand description
This object contains information about an incoming pre-checkout query.
Fields
id: StringUnique query identifier
from: UserUser who sent the query
currency: StringThree-letter ISO 4217 currency code
total_amount: usizeTotal amount in the smallest units of the currency (integer, not float). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).
invoice_payload: StringBot specified invoice payload
shipping_option_id: Option<String>Identifier of the shipping option chosen by the user
order_info: Option<OrderInfo>Order info provided by the user