Struct telexide_fork::model::ProximityAlertTriggered [−][src]
This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.
Fields
traveler: UserUser that triggered the alert
watcher: UserUser that set the alert
distance: i64The distance between the users