Struct telexide_fork::model::TextLink
source · pub struct TextLink {
pub text_block: TextBlock,
pub url: String,
}Expand description
A clickable text URL
Fields
text_block: TextBlockThe part of the text that if clicked will open an url
url: StringThe url that will be opened after user taps on the text