Struct telexide_fork::model::Voice [−][src]
pub struct Voice {
pub file_id: String,
pub file_unique_id: String,
pub duration: usize,
pub mime_type: Option<String>,
pub file_size: Option<usize>,
}Expand description
This object represents a voice note
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
duration: usizeDuration of the audio in seconds as defined by sender
mime_type: Option<String>MIME type of the file as defined by sender
file_size: Option<usize>File size