Struct telexide_fork::model::VoiceChatParticipantsInvited [−][src]
This object represents a service message about new members invited to a voice chat.
Fields
users: Option<Vec<User>>New members that were invited to the voice chat.