pub struct WebhookInfo {
    pub url: String,
    pub has_custom_certificate: bool,
    pub pending_update_count: i64,
    pub last_error_date: Option<DateTime<Utc>>,
    pub last_error_message: Option<String>,
    pub max_connections: Option<i64>,
    pub allowed_updates: Option<Vec<UpdateType>>,
    pub ip_address: Option<String>,
}
Contains information about the current status of a webhook.

Fields

url: String

Webhook URL, may be empty if webhook is not set up

has_custom_certificate: bool

True, if a custom certificate was provided for webhook certificate checks

pending_update_count: i64

Number of updates awaiting delivery

last_error_date: Option<DateTime<Utc>>

Unix time for the most recent error that happened when trying to deliver an update via webhook

last_error_message: Option<String>

Error message in human-readable format for the most recent error that happened when trying to deliver an update via webhook

max_connections: Option<i64>

Maximum allowed number of simultaneous HTTPS connections to the webhook for update delivery

allowed_updates: Option<Vec<UpdateType>>

A list of update types the bot is subscribed to. Defaults to all update types

ip_address: Option<String>

Currently used webhook IP address