Type Definition telexide_fork::prelude::CommandResult
source · pub type CommandResult = Result<(), CommandError>;Expand description
A type alias for an std Result with the CommandError as the Err and ()
as the Ok
pub type CommandResult = Result<(), CommandError>;A type alias for an std Result with the CommandError as the Err and ()
as the Ok