Module telexide_fork::api[][src]

The api module provides the API trait and APIClient, providing methods to perform requests to the telegram API

Modules

This modules provides all the objects describing the payloads to be send to the different telegram API endpoints

Structs

A default implementation of the API trait.

The response object that gets returned from the telegram API

Enums

This enum represents all the telegram API endpoints.

Traits

This trait provides methods for interacting with the telegram API.