Enum telexide_fork::api::APIEndpoint [−][src]
pub enum APIEndpoint {
Show 78 variants
GetUpdates,
GetMe,
LogOut,
Close,
SendMessage,
SetMyCommands,
GetMyCommands,
ForwardMessage,
CopyMessage,
SendPhoto,
SendAudio,
SendDocument,
SendVideo,
SendAnimation,
SendVoice,
SendVideoNote,
SendMediaGroup,
SendLocation,
EditMessageLiveLocation,
StopMessageLiveLocation,
SendVenue,
SendContact,
SendPoll,
SendDice,
SendChatAction,
GetUserProfilePhotos,
GetFile,
KickChatMember,
UnbanChatMember,
RestrictChatMember,
PromoteChatMember,
SetChatAdministratorCustomTitle,
SetChatPermissions,
ExportChatInviteLink,
CreateChatInviteLink,
EditChatInviteLink,
RevokeChatInviteLink,
SetChatPhoto,
DeleteChatPhoto,
SetChatTitle,
SetChatDescription,
PinChatMessage,
UnpinChatMessage,
UnpinAllChatMessages,
LeaveChat,
GetChat,
GetChatAdministrators,
GetChatMembersCount,
GetChatMember,
SetChatStickerSet,
DeleteChatStickerSet,
AnswerCallbackQuery,
EditMessageText,
EditMessageCaption,
EditMessageMedia,
EditMessageReplyMarkup,
StopPoll,
DeleteMessage,
SendSticker,
GetStickerSet,
UploadStickerFile,
CreateNewStickerSet,
AddStickerToSet,
SetStickerPositionInSet,
DeleteStickerFromSet,
SetStickerSetThumb,
AnswerInlineQuery,
SendInvoice,
AnswerShippingQuery,
AnswerPreCheckoutQuery,
SendGame,
SetGameScore,
GetGameHighScores,
SetWebhook,
SetPassportDataErrors,
DeleteWebhook,
GetWebhookInfo,
Other(String),
}Expand description
This enum represents all the telegram API endpoints.
It is mostly used for letting the get and post methods in the API trait know how to form the endpoint path
Variants
GetUpdates
GetMe
LogOut
Close
SendMessage
SetMyCommands
GetMyCommands
ForwardMessage
CopyMessage
SendPhoto
SendAudio
SendDocument
SendVideo
SendAnimation
SendVoice
SendVideoNote
SendMediaGroup
SendLocation
EditMessageLiveLocation
StopMessageLiveLocation
SendVenue
SendContact
SendPoll
SendDice
SendChatAction
GetUserProfilePhotos
GetFile
KickChatMember
UnbanChatMember
RestrictChatMember
PromoteChatMember
SetChatAdministratorCustomTitle
SetChatPermissions
ExportChatInviteLink
CreateChatInviteLink
EditChatInviteLink
RevokeChatInviteLink
SetChatPhoto
DeleteChatPhoto
SetChatTitle
SetChatDescription
PinChatMessage
UnpinChatMessage
UnpinAllChatMessages
LeaveChat
GetChat
GetChatAdministrators
GetChatMembersCount
GetChatMember
SetChatStickerSet
DeleteChatStickerSet
AnswerCallbackQuery
EditMessageText
EditMessageCaption
EditMessageMedia
EditMessageReplyMarkup
StopPoll
DeleteMessage
SendSticker
GetStickerSet
UploadStickerFile
CreateNewStickerSet
AddStickerToSet
SetStickerPositionInSet
DeleteStickerFromSet
SetStickerSetThumb
AnswerInlineQuery
SendInvoice
AnswerShippingQuery
AnswerPreCheckoutQuery
SendGame
SetGameScore
GetGameHighScores
SetWebhook
SetPassportDataErrors
DeleteWebhook
GetWebhookInfo
Other(String)
Tuple Fields
0: StringImplementations