Struct telexide_fork::client::ClientBuilder [−][src]
pub struct ClientBuilder { /* fields omitted */ }Expand description
A builder for the Client object to make customisation easier
Implementations
sets the webhook url for the Client to listen to
Sets the framework for your bot to use, please use the
create_framework macro for creating it
Sets the token to be used in authorizing the API requests of your bot
pub fn set_hyper_client(
&mut self,
client: Client<HttpsConnector<HttpConnector>>
) -> &mut Self
pub fn set_hyper_client(
&mut self,
client: Client<HttpsConnector<HttpConnector>>
) -> &mut Self
Sets the custom hyper client for the APIClient to use
Sets the custom API client
Set the list of update types you want your update handlers to handle
Add an update type to the list of update types you want your update handlers to handle
Remove an update type from the list of update types you want your update handlers to handle
Adds an EventHandlerFunc function for handling incoming updates
Adds an RawEventHandlerFunc function for handling incoming updates
Creates the Client object from the settings set in the
ClientBuilder object