Struct telexide_fork::client::Context[][src]

pub struct Context {
    pub api: Arc<Box<dyn API + Send>>,
    pub data: Arc<RwLock<ShareMap>>,
}
The context object is an utility object that gets passed to all event handlers, it provides access to the API client and to any custom data you have set in the data object.

Fields

api: Arc<Box<dyn API + Send>>

The API client, implementing the API trait

data: Arc<RwLock<ShareMap>>

A clone of Client::data, see its documentation for more detail

Implementations