Struct telexide_fork::client::Webhook[][src]

pub struct Webhook { /* fields omitted */ }
Handles listening to the telegram webhook and will provide you with the incoming updates

Implementations

creates a new Webhook based on the provided WebhookOptions

starts the webhandling and returns a Receiver, which will allow you to receive the incoming updates