Struct telexide_fork::client::Webhook [−][src]
pub struct Webhook { /* fields omitted */ }Expand description
Handles listening to the telegram webhook and will provide you with the incoming updates
Implementations
creates a new Webhook based on the provided WebhookOptions