Struct telexide_fork::client::WebhookOptions [−][src]
pub struct WebhookOptions {
pub url: Option<Uri>,
pub path: String,
pub port: u16,
pub ip: IpAddr,
}Expand description
Represents the options to set for the webhook handling
Fields
url: Option<Uri>path: Stringport: u16ip: IpAddrImplementations
Creates a new WebhookOptions with default values
By default it will listen on 127.0.0.1:8006 and the path being the root
Sets the port the webhook will be listening on
Sets the IP the webhook will be listening on
Sets the url of the webhook