Enum telexide_fork::model::ReplyMarkup [−][src]
pub enum ReplyMarkup {
InlineKeyboardMarkup(InlineKeyboardMarkup),
ReplyKeyboardMarkup(ReplyKeyboardMarkup),
ReplyKeyboardRemove(ReplyKeyboardRemove),
ForceReply(ForceReply),
}Expand description
Enum object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
Variants
InlineKeyboardMarkup(InlineKeyboardMarkup)
Tuple Fields
ReplyKeyboardMarkup(ReplyKeyboardMarkup)
Tuple Fields
ReplyKeyboardRemove(ReplyKeyboardRemove)
Tuple Fields
ForceReply(ForceReply)
Tuple Fields
0: ForceReplyTrait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.