Enum telexide_fork::model::UpdateContent [−][src]
pub enum UpdateContent {
Show 14 variants
Message(Message),
EditedMessage(Message),
ChannelPost(Message),
EditedChannelPost(Message),
InlineQuery(InlineQuery),
ChosenInlineResult(ChosenInlineResult),
CallbackQuery(CallbackQuery),
ShippingQuery(ShippingQuery),
PreCheckoutQuery(PreCheckoutQuery),
Poll(Poll),
PollAnswer(PollAnswer),
MyChatMember(ChatMemberUpdated),
ChatMember(ChatMemberUpdated),
Unknown,
}Expand description
The content of an Update
Variants
Message(Message)
Tuple Fields
0: MessageNew incoming message of any kind — text, photo, sticker, etc.
EditedMessage(Message)
Tuple Fields
0: MessageNew version of a message that is known to the bot and was edited
ChannelPost(Message)
Tuple Fields
0: MessageNew incoming channel post of any kind — text, photo, sticker, etc.
EditedChannelPost(Message)
Tuple Fields
0: MessageNew version of a channel post that is known to the bot and was edited
InlineQuery(InlineQuery)
Tuple Fields
0: InlineQueryNew incoming inline query
ChosenInlineResult(ChosenInlineResult)
Tuple Fields
The result of an inline query that was chosen by a user and sent to their chat partner. Please see the telegram documentation on the feedback collecting for details on how to enable these updates for your bot.
CallbackQuery(CallbackQuery)
Tuple Fields
New incoming callback query
ShippingQuery(ShippingQuery)
Tuple Fields
New incoming shipping query. Only for invoices with flexible price
PreCheckoutQuery(PreCheckoutQuery)
Tuple Fields
New incoming pre-checkout query. Contains full information about checkout
Poll(Poll)
Tuple Fields
0: PollNew poll state. Bots receive only updates about stopped polls and polls, which are sent by the bot
PollAnswer(PollAnswer)
Tuple Fields
0: PollAnswerAn user changed their answer in a non-anonymous poll. Bots receive new votes only in polls that were sent by the bot itself.
MyChatMember(ChatMemberUpdated)
Tuple Fields
The bot’s chat member status was updated in a chat. For private chats, this update is received only when the bot is blocked or unblocked by the user.
ChatMember(ChatMemberUpdated)
Tuple Fields
A chat member’s status was updated in a chat. The bot must be an administrator in the chat and must explicitly specify “chat_member” in the list of allowed_updates to receive these updates.
Unknown
An unknown update content