Struct telexide_fork::model::AdministratorMemberStatus[][src]

pub struct AdministratorMemberStatus {
Show 14 fields pub user: User, pub can_be_edited: bool, pub is_anonymous: bool, pub can_manage_chat: bool, pub can_delete_messages: bool, pub can_manage_voice_chats: bool, pub can_restrict_members: bool, pub can_promote_members: bool, pub can_change_info: bool, pub can_invite_users: bool, pub can_post_messages: Option<bool>, pub can_edit_messages: Option<bool>, pub can_pin_messages: Option<bool>, pub custom_title: Option<String>,
}
Represents a ChatMember who is an Admin of the Chat.

Fields

user: User

Information about the user

can_be_edited: bool

True, if the bot is allowed to edit administrator privileges of that user

is_anonymous: bool

Owner and administrators only. True, if the user’s presence in the chat is hidden

can_manage_chat: bool

True, if the administrator can access the chat event log, chat statistics, message statistics in channels, see channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other administrator privilege

can_delete_messages: bool

True, if the administrator can post in the channel; channels only If the administrator can delete messages of other users

can_manage_voice_chats: bool

True, if the administrator can manage voice chats

can_restrict_members: bool

True, if the administrator can restrict, ban or unban chat members

can_promote_members: bool

True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that he has promoted, directly or indirectly (promoted by administrators that were appointed by the user)

can_change_info: bool

True, if the user is allowed to change the chat title, photo and other settings

can_invite_users: bool

True, if the user is allowed to invite new users to the chat

can_post_messages: Option<bool>can_edit_messages: Option<bool>

If the administrator can edit messages of other users and can pin messages, channels only

can_pin_messages: Option<bool>

If the administrator can add new administrators with a subset of his own privileges or demote administrators that he has promoted, directly or indirectly (promoted by administrators that were appointed by him)

custom_title: Option<String>

Custom title for this user