Struct telexide_fork::model::Audio[][src]

pub struct Audio {
    pub file_id: String,
    pub file_unique_id: String,
    pub duration: usize,
    pub performer: Option<String>,
    pub title: Option<String>,
    pub file_name: Option<String>,
    pub mime_type: Option<String>,
    pub file_size: Option<usize>,
    pub thumb: Option<PhotoSize>,
}
This object represents an audio file to be treated as music by the Telegram clients.

Fields

file_id: String

Identifier for this file, which can be used to download or reuse the file

file_unique_id: String

Unique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.

duration: usize

Duration of the audio in seconds as defined by sender

performer: Option<String>

Performer of the audio as defined by sender or by audio tags

title: Option<String>

Title of the audio as defined by sender or by audio tags

file_name: Option<String>

Original filename as defined by sender

mime_type: Option<String>

MIME type of the file as defined by sender

file_size: Option<usize>

File size

thumb: Option<PhotoSize>

Thumbnail of the album cover to which the music file belongs