Struct telexide_fork::model::ChatPermissions [−][src]
pub struct ChatPermissions {
pub can_send_messages: bool,
pub can_send_media_messages: bool,
pub can_send_polls: bool,
pub can_send_other_messages: bool,
pub can_add_web_page_previews: bool,
pub can_change_info: bool,
pub can_invite_users: bool,
pub can_pin_messages: bool,
}Expand description
Describes actions that a non-administrator user is allowed to take in a chat.
Fields
can_send_messages: boolTrue, if the user is allowed to send text messages, contacts, locations and venues.
can_send_media_messages: boolTrue, if the user is allowed to send audios, documents, photos, videos, video notes and voice notes, implies can_send_messages to be true.
can_send_polls: boolTrue, if the user is allowed to send polls, implies can_send_messages to be true.
can_send_other_messages: boolTrue, if the user is allowed to send animations, games, stickers and use inline bots, implies can_send_media_messages to be true.
can_add_web_page_previews: boolTrue, if the user is allowed to add web page previews to their messages, implies can_send_media_messages to be true.
can_change_info: boolTrue, if the user is allowed to change the chat title, photo and other settings. Ignored in public supergroups.
can_invite_users: boolTrue, if the user is allowed to invite new users to the chat.
can_pin_messages: boolTrue, if the user is allowed to pin messages. Ignored in public supergroups.