Struct telexide_fork::model::Dice [−][src]
This object represents a dice with a random value from 1 to 6 for currently supported base emoji.
Fields
emoji: StringEmoji on which the dice throw animation is based
value: u8Value of the dice, 1-6 for “🎲”, “🎯” and “🎳” base emoji, 1-5 for “🏀” and “⚽” base emoji, 1-64 for “🎰” base emoji