Struct telexide_fork::model::EncryptedPassportElement [−][src]
pub struct EncryptedPassportElement {
pub element_type: TelegramPassportElement,
pub data: Option<String>,
pub phone_number: Option<String>,
pub files: Vec<PassportFile>,
pub front_side: PassportFile,
pub reverse_side: PassportFile,
pub selfie: PassportFile,
pub translation: Vec<PassportFile>,
pub hash: String,
}Expand description
Contains information about documents or other Telegram Passport elements shared with the bot by the user.
Fields
element_type: TelegramPassportElementElement type.
data: Option<String>Base64-encoded encrypted Telegram Passport element data provided by the user, available for “personal_details”, “passport”, “driver_license”, “identity_card”, “internal_passport” and “address” types. Can be decrypted and verified using the accompanying EncryptedCredentials.
phone_number: Option<String>User’s verified phone number, available only for “phone_number” type
files: Vec<PassportFile>Array of encrypted files with documents provided by the user, available for “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration” and “temporary_registration” types. Files can be decrypted and verified using the accompanying EncryptedCredentials.
front_side: PassportFileEncrypted file with the front side of the document, provided by the user. Available for “passport”, “driver_license”, “identity_card” and “internal_passport”. The file can be decrypted and verified using the accompanying EncryptedCredentials.
reverse_side: PassportFileEncrypted file with the reverse side of the document, provided by the user. Available for “driver_license” and “identity_card”. The file can be decrypted and verified using the accompanying EncryptedCredentials.
selfie: PassportFileEncrypted file with the selfie of the user holding a document, provided by the user; available for “passport”, “driver_license”, “identity_card” and “internal_passport”. The file can be decrypted and verified using the accompanying EncryptedCredentials.
translation: Vec<PassportFile>Array of encrypted files with translated versions of documents provided by the user. Available if requested for “passport”, “driver_license”, “identity_card”, “internal_passport”, “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration” and “temporary_registration” types. Files can be decrypted and verified using the accompanying EncryptedCredentials.
hash: StringBase64-encoded element hash for using in PassportElementErrorUnspecified