Struct telexide_fork::model::ForwardData [−][src]
pub struct ForwardData {
pub from: Option<User>,
pub from_chat: Option<Chat>,
pub from_message_id: Option<i64>,
pub signature: Option<String>,
pub sender_name: Option<String>,
pub date: DateTime<Utc>,
}Expand description
Holds information about the forwarded message
Fields
from: Option<User>For forwarded messages, sender of the original message
from_chat: Option<Chat>For messages forwarded from channels, information about the original channel
from_message_id: Option<i64>For messages forwarded from channels, identifier of the original message in the channel
signature: Option<String>For messages forwarded from channels, signature of the post author if present
sender_name: Option<String>Sender’s name for messages forwarded from users who disallow adding a link to their account in forwarded messages
date: DateTime<Utc>For forwarded messages, date the original message was sent in Unix time