Struct telexide_fork::model::Game [−][src]
pub struct Game {
pub title: String,
pub description: String,
pub photo: Vec<PhotoSize>,
pub text: Option<String>,
pub text_entities: Option<Vec<MessageEntity>>,
pub animation: Option<Animation>,
}Expand description
This object represents a game. Use @BotFather to create and edit games, their short names will act as unique identifiers.
Fields
title: StringTitle of the game
description: StringDescription of the game
photo: Vec<PhotoSize>Photo that will be displayed in the game message in chats.
text: Option<String>Brief description of the game or high scores included in the game message. Can be automatically edited to include current high scores for the game when the bot calls set_game_score, or manually edited using edit_message_text. 0-4096 characters.
text_entities: Option<Vec<MessageEntity>>Special entities that appear in text, such as usernames, URLs, bot commands, etc.
animation: Option<Animation>Animation that will be displayed in the game message in chats. Upload via BotFather