Struct telexide_fork::model::InlineKeyboardMarkup [−][src]
pub struct InlineKeyboardMarkup {
pub inline_keyboard: Vec<Vec<InlineKeyboardButton>>,
}Expand description
This object represents an inline keyboard that appears right next to the message it belongs to.
Fields
inline_keyboard: Vec<Vec<InlineKeyboardButton>>Vec of button rows, each represented by a Vec of
InlineKeyboardButton objects