Struct telexide_fork::model::KeyboardButton [−][src]
pub struct KeyboardButton {
pub text: String,
pub request_contact: bool,
pub request_location: bool,
pub request_poll: Option<KeyboardButtonPollType>,
}Expand description
This object represents one button of the reply keyboard. For simple text buttons String can be used instead of this object to specify text of the button.
Note: Optional fields request_contact, request_location, and
request_poll are mutually exclusive.
Fields
text: StringText of the button. If none of the optional fields are used, it will be sent as a message when the button is pressed
request_contact: boolIf true, the user’s phone number will be sent as a contact when the button is pressed. Available in private chats only
request_location: boolIf true, the user’s current location will be sent when the button is pressed. Available in private chats only
request_poll: Option<KeyboardButtonPollType>If specified, the user will be asked to create a poll and send it to the bot when the button is pressed. Available in private chats only