Struct telexide_fork::model::KeyboardButtonPollType
source · pub struct KeyboardButtonPollType {
pub poll_type: PollType,
}Expand description
This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.
Fields
poll_type: PollTypeIf quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.