Struct telexide_fork::model::Message[][src]

pub struct Message {
Show 14 fields pub message_id: i64, pub from: Option<User>, pub sender_chat: Option<Chat>, pub date: DateTime<Utc>, pub chat: Chat, pub forward_data: Option<ForwardData>, pub reply_to_message: Option<Box<Message>>, pub via_bot: Option<User>, pub edit_date: Option<DateTime<Utc>>, pub author_signature: Option<String>, pub content: MessageContent, pub connected_website: Option<String>, pub passport_data: Option<PassportData>, pub reply_markup: Option<InlineKeyboardMarkup>,
}
This object represents a message.

Fields

message_id: i64

Unique message identifier inside this chat

from: Option<User>

Sender, empty for messages sent to channels

sender_chat: Option<Chat>

Sender of the message, sent on behalf of a chat. The channel itself for channel messages. The supergroup itself for messages from anonymous group administrators. The linked channel for messages automatically forwarded to the discussion group

date: DateTime<Utc>

Date the message was sent

chat: Chat

Conversation the message belongs to

forward_data: Option<ForwardData>

Data about what message it was forwarded from

reply_to_message: Option<Box<Message>>via_bot: Option<User>

Bot through which the message was sent

edit_date: Option<DateTime<Utc>>

Date the message was last edited in Unix time

author_signature: Option<String>

Signature of the post author for messages in channels

content: MessageContent

The content of the message

connected_website: Option<String>

The domain name of the website on which the user has logged in.

passport_data: Option<PassportData>

Telegram Passport data

reply_markup: Option<InlineKeyboardMarkup>

Inline keyboard attached to the message. login_url buttons are represented as ordinary url buttons.

Implementations