Struct telexide_fork::model::PassportData [−][src]
pub struct PassportData {
pub data: Vec<EncryptedCredentials>,
pub credentials: EncryptedCredentials,
}Expand description
Contains information about Telegram Passport data shared with the bot by the user.
Fields
data: Vec<EncryptedCredentials>Vec with information about documents and other Telegram Passport elements that was shared with the bot
credentials: EncryptedCredentialsEncrypted credentials required to decrypt the data