Struct telexide_fork::model::PhotoSize [−][src]
pub struct PhotoSize {
pub file_id: String,
pub file_unique_id: String,
pub width: usize,
pub height: usize,
pub file_size: Option<usize>,
}Expand description
This object represents one size of a photo or a file / sticker thumbnail
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
width: usizePhoto width
height: usizePhoto height
file_size: Option<usize>File size