Struct telexide_fork::model::PrivateChat[][src]

pub struct PrivateChat {
    pub id: i64,
    pub username: Option<String>,
    pub first_name: Option<String>,
    pub bio: Option<String>,
    pub last_name: Option<String>,
    pub photo: Option<ChatPhoto>,
}
A private chat object, also known as a DM, between the bot and an user

Fields

id: i64

Unique identifier for this chat

username: Option<String>

Username if available

first_name: Option<String>

First name of the other party

bio: Option<String>

Bio of the other party in a private chat. Returned only in get_chat.

last_name: Option<String>

Last name of the other party

photo: Option<ChatPhoto>

Chat photo. Returned only in get_chat.