Struct telexide_fork::model::RestrictedMemberStatus [−][src]
pub struct RestrictedMemberStatus {
pub user: User,
pub until_date: Option<DateTime<Utc>>,
pub can_change_info: bool,
pub can_invite_users: bool,
pub can_pin_messages: bool,
pub is_member: bool,
pub can_send_messages: bool,
pub can_send_media_messages: bool,
pub can_send_polls: bool,
pub can_send_other_messages: bool,
pub can_add_web_page_previews: bool,
}Expand description
Represents a restricted ChatMember of a Chat.
Fields
user: UserInformation about the user
until_date: Option<DateTime<Utc>>Date when restrictions will be lifted for this user; unix time
can_change_info: boolTrue, if the user is allowed to change the chat title, photo and other settings
can_invite_users: boolTrue, if the user is allowed to invite new users to the chat
can_pin_messages: boolTrue, if the user is allowed to pin messages; groups and supergroups only
is_member: boolTrue, if the user is a member of the chat at the moment of the request
can_send_messages: boolTrue, if the user is allowed to send text messages, contacts, locations and venues
can_send_media_messages: boolTrue, if the user is allowed to send audios, documents, photos, videos, video notes and voice notes
can_send_polls: boolTrue, if the user is allowed to send polls
can_send_other_messages: boolTrue, if the user is allowed to send animations, games, stickers and use inline bots
can_add_web_page_previews: boolTrue, if the user is allowed to add web page previews to their messages