Struct telexide_fork::model::SuperGroupChat[][src]

pub struct SuperGroupChat {
Show 13 fields pub id: i64, pub title: String, pub username: Option<String>, pub photo: Option<ChatPhoto>, pub description: Option<String>, pub invite_link: Option<String>, pub pinned_message: Option<Box<Message>>, pub permissions: Option<ChatPermissions>, pub slow_mode_delay: Option<usize>, pub sticker_set_name: Option<String>, pub can_set_sticker_set: Option<bool>, pub linked_chat_id: Option<i64>, pub location: Option<ChatLocation>,
}
A supergroup object (a group with more than 200 members)

Fields

id: i64title: String

Title

username: Option<String>

Username if available

photo: Option<ChatPhoto>

Chat photo. Returned only in get_chat.

description: Option<String>

Description. Returned only in get_chat.

invite_link: Option<String>

Chat invite link

pinned_message: Option<Box<Message>>

Pinned message. Returned only in get_chat.

permissions: Option<ChatPermissions>

Default chat member permissions. Returned only in get_chat.

slow_mode_delay: Option<usize>

The minimum allowed delay between consecutive messages sent by each unprivileged user. Returned only in get_chat.

sticker_set_name: Option<String>

Name of group sticker set. Returned only in get_chat.

can_set_sticker_set: Option<bool>

True, if the bot can change the group sticker set. Returned only in get_chat.

linked_chat_id: Option<i64>

Unique identifier for the linked chat, i.e. the discussion group identifier for a channel and vice versa; for supergroups and channel chats. Returned only in get_chat.

location: Option<ChatLocation>

For supergroups, the location to which the supergroup is connected. Returned only in get_chat.