Struct telexide_fork::model::Update [−][src]
pub struct Update {
pub update_id: i64,
pub content: UpdateContent,
}Expand description
This object represents an incoming update
Fields
update_id: i64The update‘s unique identifier. Update identifiers start from a certain positive number and increase sequentially. This ID becomes especially handy if you’re using Webhooks, since it allows you to ignore repeated updates or to restore the correct update sequence, should they get out of order. If there are no new updates for at least a week, then identifier of the next update will be chosen randomly instead of sequentially.
content: UpdateContentThe content of the incoming update