Struct telexide_fork::model::User [−][src]
pub struct User {
pub id: i64,
pub is_bot: bool,
pub first_name: String,
pub last_name: Option<String>,
pub username: Option<String>,
pub language_code: Option<String>,
pub can_join_groups: Option<bool>,
pub can_read_all_group_messages: Option<bool>,
pub supports_inline_queries: Option<bool>,
}Expand description
This object represents a Telegram user or bot.
Fields
id: i64Unique identifier for this user or bot
is_bot: boolTrue, if this user is a bot
first_name: StringUser‘s or bot’s first name
last_name: Option<String>User‘s or bot’s last name
username: Option<String>User‘s or bot’s username
language_code: Option<String>IETF language tag of the user’s language
can_join_groups: Option<bool>True, if the bot can be invited to groups. Returned only in get_me.
can_read_all_group_messages: Option<bool>True, if privacy mode is disabled for the bot. Returned only in
get_me.
supports_inline_queries: Option<bool>True, if the bot supports inline queries. Returned only in get_me.