Struct telexide_fork::model::VideoNote [−][src]
pub struct VideoNote {
pub file_id: String,
pub file_unique_id: String,
pub length: usize,
pub duration: usize,
pub thumb: Option<PhotoSize>,
pub file_size: Option<usize>,
}Expand description
This object represents a video message
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
length: usizeVideo width and height (diameter of the video message) as defined by sender
duration: usizeDuration of the video in seconds as defined by sender
thumb: Option<PhotoSize>Video thumbnail
file_size: Option<usize>File size